@@ -142,6 +142,10 @@ class HPOTask(AbstractObject):
     def hyperparameters(self):
         return self._hyperparameters
     
+    @property
+    def run_mode(self):
+        return self._run_mode
+    
     @property
     def log_dir(self) -> str:
         return self._log_dir
@@ -161,10 +165,11 @@ class HPOTask(AbstractObject):
     def __init__(self, model:Optional[Callable]=None, search_space:Optional[Dict]=None,
                  verbosity:str="INFO"):
         super().__init__(verbosity=verbosity)
-        self._resource = None
+        self._resource = None        
         self.reset()
         self.set_model(model)
         self.set_search_space(search_space)
+        self.set_run_mode("local")
         
     def setup(self, project_name:Optional[str]=None, algorithm:str=kDefaultSearchAlgorithm,
               metric:str=kDefaultMetric, mode:str=kDefaultMetricMode, num_trials:int=kDefaultTrials,
@@ -415,7 +420,9 @@ class HPOTask(AbstractObject):
             
         self._start_timestamp = start = time.time()
         self._start_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
-
+        
+        es.setup(self.run_mode)
+        
         # get model parameters
         if self.algorithm == 'tune':
             tune_config_space = self.get_search_space(self.search_space, algorithm='tune')
@@ -470,7 +477,7 @@ class HPOTask(AbstractObject):
                 datadir = es.get_datadir()
                 extracted_files = helper.extract_tarball(datadir, datadir)
             ray.init(include_dashboard=False)
-            # lru_evict=True      
+   
             if not self.log_dir:
                 local_dir = os.path.join(temp_dir.name, 'log')
             else:
@@ -495,6 +502,7 @@ class HPOTask(AbstractObject):
             self.stdout.info(f"Trial Scheduler         : {self.scheduler}")
             self.stdout.info(f"Number of Search Points : {num_samples}")
             self.stdout.info("--------------------------------------------------------------------------------")
+            cwd = os.getcwd()
             analysis = tune.run(
                 model,
                 name=self.project_name,
@@ -507,6 +515,7 @@ class HPOTask(AbstractObject):
                 local_dir=local_dir,
                 callbacks=callbacks,
                 stop=self.stop)
+            os.chdir(cwd)
         finally:
             ray.shutdown()
             # remove the extracted tar files
@@ -546,8 +555,8 @@ class HPOTask(AbstractObject):
         from ray.tune.logger import NoopLogger, MLFLowLogger
         return [NoopLogger, MLFLowLogger]
     
-    def set_run_mode(self, mode:str='local'):
-        es.setup(mode)
+    def set_run_mode(self, run_mode:str='local'):
+        self._run_mode = run_mode
 
     def parse_project_config(self, source:[Dict, str]):
         
@@ -606,6 +615,7 @@ class HPOTask(AbstractObject):
 
         task = cls()
         task.set_run_mode(mode)
+        es.setup(mode, silent=True)
         
         task.parse_project_config(source)
 
